Package: ComPrAn
Type: Package
Title: Complexome Profiling Analysis package
Version: 1.21.0
Authors@R: 
    c(person(given = "Rick",
           family = "Scavetta",
           role = c("aut"),
           email = "rick@scavetta.academy"),
      person(given = "Petra",
           family = "Palenikova",
           role = c("aut", "cre"),
           email = "palenikova3@gmail.com",
           comment = c(ORCID = "0000-0002-2465-4370")))
Description: This package is for analysis of SILAC labeled complexome
        profiling data. It uses peptide table in tab-delimited format
        as an input and produces ready-to-use tables and plots.
License: MIT + file LICENSE
Encoding: UTF-8
Imports: data.table, dplyr, forcats, ggplot2, magrittr, purrr, tidyr,
        rlang, stringr, shiny, DT, RColorBrewer, VennDiagram, rio,
        scales, shinydashboard, shinyjs, stats, tibble, grid
RoxygenNote: 7.1.1
Suggests: testthat (>= 2.1.0), knitr, rmarkdown
VignetteBuilder: knitr
biocViews: MassSpectrometry, Proteomics, Visualization
Config/pak/sysreqs: cmake make libicu-dev libuv1-dev libssl-dev
        libx11-dev zlib1g-dev
Repository: https://bioc.r-universe.dev
Date/Publication: 2026-04-28 12:55:09 UTC
RemoteUrl: https://github.com/bioc/ComPrAn
RemoteRef: HEAD
RemoteSha: cd4d3ebdeda442811cc0fdaa82fa63ec722af5f0
NeedsCompilation: no
Packaged: 2026-05-26 06:03:04 UTC; root
Author: Rick Scavetta [aut],
  Petra Palenikova [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-2465-4370>)
Maintainer: Petra Palenikova <palenikova3@gmail.com>
Built: R 4.6.0; ; 2026-05-26 06:04:54 UTC; unix
