# Generated by roxygen2: do not edit by hand

export(allPeptidesPlot)
export(assignClusters)
export(cleanData)
export(clusterComp)
export(compranApp)
export(exportClusterAssignments)
export(getNormTable)
export(groupHeatMap)
export(makeBarPlotClusterSummary)
export(oneGroupTwoLabelsCoMigration)
export(onlyInOneLabelState)
export(peptideImport)
export(pickPeptide)
export(protImportForAnalysis)
export(proteinPlot)
export(simplifyProteins)
export(splitModLab)
export(toFilter)
export(twoGroupsWithinLabelCoMigration)
import(DT)
import(RColorBrewer)
import(VennDiagram)
import(dplyr)
import(forcats)
import(ggplot2)
import(grid)
import(rio)
import(scales)
import(shinydashboard)
import(shinyjs)
importFrom(data.table,fread)
importFrom(magrittr,"%>%")
importFrom(purrr,map_df)
importFrom(rlang,.data)
importFrom(stats,as.dist)
importFrom(stats,cor)
importFrom(stats,cutree)
importFrom(stats,hclust)
importFrom(stats,median)
importFrom(stats,reorder)
importFrom(stringr,str_detect)
importFrom(stringr,str_extract)
importFrom(stringr,str_remove)
importFrom(stringr,str_split)
importFrom(tibble,rowid_to_column)
importFrom(tidyr,gather)
importFrom(tidyr,replace_na)
importFrom(tidyr,separate)
importFrom(tidyr,spread)
